@@ -1,19 +1,17 @@
 // SPDX-License-Identifier: Apache-2.0 AND MIT
 
-#undef USE_ENCODING_LIB
-#include "oqs_prov.h"
-#include "test_common.h"
-
-#include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include <openssl/core_names.h>
 #include <openssl/crypto.h>
 #include <openssl/err.h>
 #include <openssl/evp.h>
 #include <openssl/provider.h>
+#include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#include "oqs_prov.h"
+#include "test_common.h"
 
 ///// OQS_TEMPLATE_FRAGMENT_HYBRID_SIG_ALGS_START
 
@@ -40,6 +38,10 @@ const char *kHybridSignatureAlgorithms[] = {
     "p384_sphincssha2192fsimple",
     "p256_sphincsshake128fsimple",
     "rsa3072_sphincsshake128fsimple",
+    "p256_mayo1",
+    "p256_mayo2",
+    "p384_mayo3",
+    "p521_mayo5",
     NULL,
 };
 ///// OQS_TEMPLATE_FRAGMENT_HYBRID_SIG_ALGS_END
@@ -55,7 +57,7 @@ const char *kHybridKEMAlgorithms[] = {
     "p384_kyber768",        "x448_kyber768",      "x25519_kyber768",
     "p256_kyber768",        "p521_kyber1024",     "p256_mlkem512",
     "x25519_mlkem512",      "p384_mlkem768",      "x448_mlkem768",
-    "x25519_mlkem768",      "p256_mlkem768",      "p521_mlkem1024",
+    "X25519MLKEM768",       "SecP256r1MLKEM768",  "p521_mlkem1024",
     "p384_mlkem1024",       "p256_bikel1",        "x25519_bikel1",
     "p384_bikel3",          "x448_bikel3",        "p521_bikel5",
     "p256_hqc128",          "x25519_hqc128",      "p384_hqc192",
@@ -68,8 +70,7 @@ const char *kHybridKEMAlgorithms[] = {
  * \param s String to test.
  *
  * \return 1 if `s` is in `list`, else 0. */
-static int is_string_in_list(const char **list, const char *s)
-{
+static int is_string_in_list(const char **list, const char *s) {
     for (; *list != NULL && strcmp(*list, s) != 0; ++list)
         ;
     if (*list != NULL) {
@@ -83,7 +84,7 @@ static int is_string_in_list(const char **list, const char *s)
  * \param alg Algorithm name.
  *
  * \returns 1 if hybrid, else 0. */
-#define is_signature_algorithm_hybrid(_alg_) \
+#define is_signature_algorithm_hybrid(_alg_)                                   \
     is_string_in_list(kHybridSignatureAlgorithms, (_alg_))
 
 /** \brief Indicates if an kem algorithm is hybrid or not.
@@ -91,7 +92,7 @@ static int is_string_in_list(const char **list, const char *s)
  * \param alg Algorithm name.
  *
  * \returns 1 if hybrid, else 0. */
-#define is_kem_algorithm_hybrid(_alg_) \
+#define is_kem_algorithm_hybrid(_alg_)                                         \
     is_string_in_list(kHybridKEMAlgorithms, (_alg_))
 
 /** \brief A pair of keys. */
@@ -116,8 +117,7 @@ struct KeyPair {
 /** \brief Frees the memory occupied by a KeyPair.
  *
  * \param kp Keypair to free. */
-static void keypair_free(struct KeyPair *kp)
-{
+static void keypair_free(struct KeyPair *kp) {
     free(kp->pubkey);
     free(kp->privkey);
 }
@@ -125,8 +125,7 @@ static void keypair_free(struct KeyPair *kp)
 /** \brief Initializes an OpenSSL top-level context.
  *
  * \returns The top-level context, or `NULL` if an error occurred. */
-static OSSL_LIB_CTX *init_openssl(void)
-{
+static OSSL_LIB_CTX *init_openssl(void) {
     OSSL_LIB_CTX *ctx;
 
     if (!(ctx = OSSL_LIB_CTX_new())) {
@@ -143,8 +142,7 @@ static OSSL_LIB_CTX *init_openssl(void)
  * \paran alg The algorithm to use.
  *
  * \returns The EVP_PKEY context, or `NULL` if an error occurred. */
-static EVP_PKEY_CTX *init_EVP_PKEY_CTX(OSSL_LIB_CTX *libctx, const char *alg)
-{
+static EVP_PKEY_CTX *init_EVP_PKEY_CTX(OSSL_LIB_CTX *libctx, const char *alg) {
     EVP_PKEY_CTX *ctx;
 
     if (!(ctx = EVP_PKEY_CTX_new_from_name(libctx, alg, NULL))) {
@@ -163,14 +161,13 @@ static EVP_PKEY_CTX *init_EVP_PKEY_CTX(OSSL_LIB_CTX *libctx, const char *alg)
  * \param ctx EVP_PKEY context.
  *
  * \returns 0 on success. */
-static int init_keygen(EVP_PKEY_CTX *ctx)
-{
+static int init_keygen(EVP_PKEY_CTX *ctx) {
     int err;
 
     if ((err = EVP_PKEY_keygen_init(ctx)) == -2) {
-        fputs(cRED
-              "`EVP_PKEY_keygen_init` failed, couldn't initialize keygen: not "
-              "supported" cNORM "\n",
+        fputs(cRED "`EVP_PKEY_keygen_init` failed, couldn't initialize "
+                   "keygen: not "
+                   "supported" cNORM "\n",
               stderr);
     } else if (err <= 0) {
         fputs(cRED
@@ -188,17 +185,14 @@ static int init_keygen(EVP_PKEY_CTX *ctx)
  * \param ctx EVP_PKEY context.
  *
  * \returns The private key, or `NULL` if an error occurred. */
-static EVP_PKEY *generate_private_key(EVP_PKEY_CTX *ctx)
-{
+static EVP_PKEY *generate_private_key(EVP_PKEY_CTX *ctx) {
     EVP_PKEY *private_key = NULL;
     int err;
 
     if ((err = EVP_PKEY_generate(ctx, &private_key)) == -2) {
-        fputs(
-            cRED
-            "`EVP_PKEY_generate` failed, couldn't generate: not supported" cNORM
-            "\n",
-            stderr);
+        fputs(cRED "`EVP_PKEY_generate` failed, couldn't generate: not "
+                   "supported" cNORM "\n",
+              stderr);
     } else if (err <= 0) {
         fputs(cRED "`EVP_PKEY_generate` failed, couldn't generate: ", stderr);
         ERR_print_errors_fp(stderr);
@@ -217,14 +211,13 @@ static EVP_PKEY *generate_private_key(EVP_PKEY_CTX *ctx)
  *
  * \returns 0 on success. */
 static int get_param_octet_string(const EVP_PKEY *key, const char *param_name,
-                                  uint8_t **buf, size_t *buf_len)
-{
+                                  uint8_t **buf, size_t *buf_len) {
     *buf = NULL;
     *buf_len = 0;
     int ret = -1;
 
-    if (EVP_PKEY_get_octet_string_param(key, param_name, NULL, 0, buf_len)
-        != 1) {
+    if (EVP_PKEY_get_octet_string_param(key, param_name, NULL, 0, buf_len) !=
+        1) {
         fprintf(stderr,
                 cRED
                 "`EVP_PKEY_get_octet_string_param` failed with param `%s`: ",
@@ -238,8 +231,7 @@ static int get_param_octet_string(const EVP_PKEY *key, const char *param_name,
         goto out;
     }
     if (EVP_PKEY_get_octet_string_param(key, param_name, *buf, *buf_len,
-                                        buf_len)
-        != 1) {
+                                        buf_len) != 1) {
         fprintf(stderr,
                 cRED
                 "`EVP_PKEY_get_octet_string_param` failed with param `%s`: ",
@@ -263,8 +255,7 @@ out:
  *
  * \returns 0 on success. */
 static int private_key_params_get_classical_keys(const EVP_PKEY *private_key,
-                                                 struct KeyPair *out)
-{
+                                                 struct KeyPair *out) {
     int ret = -1;
 
     if (get_param_octet_string(private_key,
@@ -294,8 +285,7 @@ out:
  *
  * \returns 0 on success. */
 static int private_key_params_get_pq_keys(const EVP_PKEY *private_key,
-                                          struct KeyPair *out)
-{
+                                          struct KeyPair *out) {
     int ret = -1;
 
     if (get_param_octet_string(private_key, OQS_HYBRID_PKEY_PARAM_PQ_PUB_KEY,
@@ -316,15 +306,15 @@ out:
     return ret;
 }
 
-/** \brief Extracts the combination of classical+hybrid keys from an hybrid key.
+/** \brief Extracts the combination of classical+hybrid keys from an hybrid
+ * key.
  *
  * \param private_key The private key.
  * \param[out] out Key pair where to write the keys.
  *
  * \returns 0 on success. */
 static int private_key_params_get_full_keys(const EVP_PKEY *private_key,
-                                            struct KeyPair *out)
-{
+                                            struct KeyPair *out) {
     int ret = -1;
 
     if (get_param_octet_string(private_key, OSSL_PKEY_PARAM_PUB_KEY,
@@ -352,14 +342,14 @@ out:
  * \param classical_n Length in bytes of `classical`.
  * \param pq Quantum-resistant key.
  * \param pq_n Length in bytes of `pq`.
+ * \param reverse Reverses the order of shares
  * \param[out] buf Out buffer.
  * \param[out] buf_n Length in bytes of `buf`.
  *
  * \returns 0 on success. */
 static int reconstitute_keys(const uint8_t *classical, const size_t classical_n,
-                             const uint8_t *pq, const size_t pq_n,
-                             uint8_t **buf, size_t *buf_len)
-{
+                             const uint8_t *pq, const size_t pq_n, int reverse,
+                             uint8_t **buf, size_t *buf_len) {
     uint32_t header;
     int ret = -1;
 
@@ -374,8 +364,14 @@ static int reconstitute_keys(const uint8_t *classical, const size_t classical_n,
     (*buf)[1] = header >> 0x10;
     (*buf)[2] = header >> 0x8;
     (*buf)[3] = header;
-    memcpy(*buf + sizeof(header), classical, classical_n);
-    memcpy(*buf + sizeof(header) + classical_n, pq, pq_n);
+
+    if (!reverse) {
+        memcpy(*buf + sizeof(header), classical, classical_n);
+        memcpy(*buf + sizeof(header) + classical_n, pq, pq_n);
+    } else {
+        memcpy(*buf + sizeof(header), pq, pq_n);
+        memcpy(*buf + sizeof(header) + pq_n, classical, classical_n);
+    }
     ret = 0;
 
 out:
@@ -391,26 +387,28 @@ out:
  * \returns 0 on success. */
 static int keypairs_verify_consistency(const struct KeyPair *classical,
                                        const struct KeyPair *pq,
-                                       const struct KeyPair *comb)
-{
-    uint8_t *reconstitution;
+                                       const struct KeyPair *comb) {
+    uint8_t *reconstitution, *reconstitution_rev;
     size_t n;
     int ret = -1;
 
     if (reconstitute_keys(classical->pubkey, classical->pubkey_len, pq->pubkey,
-                          pq->pubkey_len, &reconstitution, &n)) {
+                          pq->pubkey_len, 1, &reconstitution, &n)) {
+        goto out;
+    }
+    if (reconstitute_keys(classical->pubkey, classical->pubkey_len, pq->pubkey,
+                          pq->pubkey_len, 0, &reconstitution_rev, &n)) {
         goto out;
     }
     if (n != comb->pubkey_len) {
-        fprintf(
-            stderr,
-            cRED
-            "expected %#zx byte(s) for reconstitution of pubkey, got %#zx" cNORM
-            "\n",
-            comb->pubkey_len, n);
+        fprintf(stderr,
+                cRED "expected %#zx byte(s) for reconstitution of "
+                     "pubkey, got %#zx" cNORM "\n",
+                comb->pubkey_len, n);
         goto free_reconstitute;
     }
-    if (memcmp(reconstitution, comb->pubkey, n)) {
+    if (memcmp(reconstitution, comb->pubkey, n) &&
+        memcmp(reconstitution_rev, comb->pubkey, n)) {
         fputs(cRED "pubkey and comb->pubkey differ " cNORM "\n", stderr);
         fputs(cRED "pubkey: ", stderr);
         hexdump(reconstitution, n);
@@ -420,19 +418,27 @@ static int keypairs_verify_consistency(const struct KeyPair *classical,
         goto free_reconstitute;
     }
     free(reconstitution);
+    free(reconstitution_rev);
 
     if (reconstitute_keys(classical->privkey, classical->privkey_len,
-                          pq->privkey, pq->privkey_len, &reconstitution, &n)) {
+                          pq->privkey, pq->privkey_len, 0, &reconstitution,
+                          &n)) {
+        goto out;
+    }
+    if (reconstitute_keys(classical->privkey, classical->privkey_len,
+                          pq->privkey, pq->privkey_len, 1, &reconstitution_rev,
+                          &n)) {
         goto out;
     }
     if (n != comb->privkey_len) {
-        fprintf(
-            stderr,
-            "expected %#zx byte(s) for reconstitution of privkey, got %#zx\n",
-            comb->privkey_len, n);
+        fprintf(stderr,
+                "expected %#zx byte(s) for reconstitution of privkey, "
+                "got %#zx\n",
+                comb->privkey_len, n);
         goto free_reconstitute;
     }
-    if (memcmp(reconstitution, comb->privkey, n)) {
+    if (memcmp(reconstitution, comb->privkey, n) &&
+        memcmp(reconstitution_rev, comb->privkey, n)) {
         fputs(cRED "privkey and comb->privkey differ" cNORM "\n", stderr);
         fputs(cRED "privkey: ", stderr);
         hexdump(reconstitution, n);
@@ -445,6 +451,7 @@ static int keypairs_verify_consistency(const struct KeyPair *classical,
 
 free_reconstitute:
     free(reconstitution);
+    free(reconstitution_rev);
 
 out:
     return ret;
@@ -456,8 +463,7 @@ out:
  * \param algname Algorithm name.
  *
  * \returns 0 on success. */
-static int test_algorithm(OSSL_LIB_CTX *libctx, const char *algname)
-{
+static int test_algorithm(OSSL_LIB_CTX *libctx, const char *algname) {
     EVP_PKEY_CTX *evp_pkey_ctx;
     EVP_PKEY *private_key;
     struct KeyPair classical_keypair;
@@ -513,8 +519,7 @@ out:
     return ret;
 }
 
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
     OSSL_LIB_CTX *libctx;
     OSSL_PROVIDER *default_provider;
     OSSL_PROVIDER *oqs_provider;
@@ -550,6 +555,7 @@ int main(int argc, char **argv)
         fprintf(stderr, cRED "  No signature algorithms found" cNORM "\n");
         ERR_print_errors_fp(stderr);
         ++errcnt;
+        goto next_alg;
     }
 
     for (; algs->algorithm_names != NULL; ++algs) {
@@ -566,6 +572,7 @@ int main(int argc, char **argv)
         }
     }
 
+next_alg:
     algs = OSSL_PROVIDER_query_operation(oqs_provider, OSSL_OP_KEM,
                                          &query_nocache);
     if (!algs) {
